E200
====

E200 is designed to load data from FACET at SLAC National 
Accelerator Laboratory. Data files can be found on
pwfa.slac.stanford.edu from inside SLAC's vpn/internet.

Installation
------------

To install, download, and in the main directory run:

        pip install E200

Source Code
-----------

Source code can be found in the E200 subdirectory.

E200 depends on numpy, scipy.

Documentation
-------------

More in-depth documentation can be found at:

http://e200.readthedocs.org
